@@ -1,6 +1,6 @@
 #[cfg(feature = "clap")]
-use rad::cli::Cli;
-use rad::error::RadError;
+use rad::Cli;
+use rad::RadError;
 
 pub fn main() -> Result<(), RadError> {
 
