@@ -1,5 +1,5 @@
-pub mod error;
-pub mod processor;
+mod error;
+mod processor;
 
 pub(crate) mod basic;
 pub(crate) mod consts;
@@ -8,11 +8,16 @@ pub(crate) mod models;
 pub(crate) mod utils;
 pub(crate) mod arg_parser;
 
+pub use error::RadError;
+pub use processor::Processor;
+
 // Optional
 
 // Binary option
 #[cfg(feature = "clap")]
-pub mod cli;
+mod cli;
+#[cfg(feature = "clap")]
+pub use cli::Cli;
 
 // Only for csv
 #[cfg(feature = "csv")]
