@@ -20,6 +20,7 @@ struct MacroFragment {
     pub preceding: bool,
     pub yield_literal : bool,
     pub trimmed : bool,
+    pub deterred : bool,
 }
 
 impl MacroFragment {
@@ -33,6 +34,7 @@ impl MacroFragment {
             preceding: false,
             yield_literal : false,
             trimmed: false,
+            deterred: false,
         }
     }
 
@@ -43,7 +45,8 @@ impl MacroFragment {
         self.pipe = false; 
         self.greedy = false; 
         self.yield_literal = false;
-        self.trimmed= false; 
+        self.trimmed = false; 
+        self.deterred = false;
     }
 
     fn is_empty(&self) -> bool {
@@ -545,6 +548,7 @@ impl Processor {
                     '+' => frag.greedy = true,
                     '*' => frag.yield_literal = true,
                     '^' => frag.trimmed = true,
+                    '?' => frag.deterred = true,
                     _ => frag.name.push(ch) 
                 }
             },
@@ -566,7 +570,7 @@ impl Processor {
             frag.clear()
         } else { // Invoke macro
             // Try to evaluate
-            let evaluation_result = self.evaluate(level, caller, &frag.name, &frag.args, frag.greedy || self.always_greedy);
+            let evaluation_result = self.evaluate(level, caller, &frag.name, &frag.args, frag.greedy || self.always_greedy, frag.deterred);
 
             // If panicked, this means unrecoverable error occured.
             if let Err(error) = evaluation_result {
@@ -582,22 +586,29 @@ impl Processor {
             // else it is ok to proceed.
             // thus it is safe to unwrap it
             if let Some(mut content) = evaluation_result.unwrap() {
-                if frag.pipe {
-                    self.pipe_value = content;
-                    lexor.escape_nl = true;
-                }
                 // If content is none
                 // Ignore new line after macro evaluation until any character
-                else if content.len() == 0 {
+                if content.len() == 0 {
                     lexor.escape_nl = true;
                 } else {
+                    // This should come first
+                    if frag.deterred {
+                        content = self.parse_chunk(level, &frag.name, &content)?;
+                    }
                     if frag.trimmed {
                         content = Utils::trim(&content)?;
                     }
                     if frag.yield_literal {
                         content = format!("\\*{}*\\", content);
                     }
-                    remainder.push_str(&content);
+                    // NOTE
+                    // This should come later!!
+                    if frag.pipe {
+                        self.pipe_value = content;
+                        lexor.escape_nl = true;
+                    } else {
+                        remainder.push_str(&content);
+                    }
                 }
             } else { // Failed to invoke
                 // because macro doesn't exist
@@ -654,11 +665,11 @@ impl Processor {
     // Evaluate can be nested deeply
     // Disable caller for temporary
     /// Evaluate detected macro usage
-    fn evaluate(&mut self,level: usize, caller: &str, name: &str, args: &str, greedy: bool) -> Result<Option<String>, RadError> {
+    fn evaluate(&mut self,level: usize, caller: &str, name: &str, raw_args: &str, greedy: bool, deterred: bool) -> Result<Option<String>, RadError> {
         let level = level + 1;
         // This parses and processes arguments
         // and macro should be evaluated after
-        let args = self.parse_chunk(level, name, args)?; 
+        let args: String = if !deterred { self.parse_chunk(level, name, raw_args)? } else { raw_args.to_owned() };
 
         // Find local macro
         // The macro can be  the one defined in parent macro
@@ -714,7 +725,7 @@ impl Processor {
             //Set arg to be substitued
             self.map.new_local(level + 1, arg_type ,&args[idx]);
         }
-        // parse the Chunk
+        // Process the rule body
         let result = self.parse_chunk(level, &name, &rule.body)?;
 
         Ok(Some(result))
